<?php
/**
 * VW Parallax Theme Customizer
 *
 * @package VW Parallax
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function vw_parallax_custom_controls() {

    load_template( trailingslashit( get_template_directory() ) . '/inc/custom-controls.php' );
}
add_action( 'customize_register', 'vw_parallax_custom_controls' );

function vw_parallax_customize_register( $wp_customize ) {

	load_template( trailingslashit( get_template_directory() ) . 'inc/customize-homepage/class-customize-homepage.php' );

	//add home page setting pannel
	$wp_customize->add_panel( 'vw_parallax_panel_id', array(
	    'priority' => 10,
	    'capability' => 'edit_theme_options',
	    'theme_supports' => '',
	    'title' => __( 'VW Settings', 'vw-parallax' ),
	    'description' => __( 'Description of what this panel does.', 'vw-parallax' ),
	) );

	$wp_customize->add_section( 'vw_parallax_left_right', array(
    	'title'      => __( 'General Settings', 'vw-parallax' ),
		'priority'   => 30,
		'panel' => 'vw_parallax_panel_id'
	) );

	$wp_customize->add_setting('vw_parallax_width_option',array(
        'default' => __('Full Width','vw-parallax'),
        'sanitize_callback' => 'vw_parallax_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Parallax_Image_Radio_Control($wp_customize, 'vw_parallax_width_option', array(
        'type' => 'select',
        'label' => __('Width Layouts','vw-parallax'),
        'description' => __('Here you can change the width layout of Website.','vw-parallax'),
        'section' => 'vw_parallax_left_right',
        'choices' => array(
            'Full Width' => get_template_directory_uri().'/assets/images/full-width.png',
            'Wide Width' => get_template_directory_uri().'/assets/images/wide-width.png',
            'Boxed' => get_template_directory_uri().'/assets/images/boxed-width.png',
    ))));

	// Add Settings and Controls for Layout
	$wp_customize->add_setting('vw_parallax_theme_options',array(
        'default' => __('Right Sidebar','vw-parallax'),
        'sanitize_callback' => 'vw_parallax_sanitize_choices'	        
	) );
	$wp_customize->add_control('vw_parallax_theme_options', array(
        'type' => 'select',
        'label' => __('Post Sidebar Layout','vw-parallax'),
        'description' => __('Here you can change the sidebar layout for posts. ','vw-parallax'),
        'section' => 'vw_parallax_left_right',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','vw-parallax'),
            'Right Sidebar' => __('Right Sidebar','vw-parallax'),
            'One Column' => __('One Column','vw-parallax'),
            'Three Columns' => __('Three Columns','vw-parallax'),
            'Four Columns' => __('Four Columns','vw-parallax'),
            'Grid Layout' => __('Grid Layout','vw-parallax')
        ),
	));

	$wp_customize->add_setting('vw_parallax_page_layout',array(
        'default' => __('One Column','vw-parallax'),
        'sanitize_callback' => 'vw_parallax_sanitize_choices'
	));
	$wp_customize->add_control('vw_parallax_page_layout',array(
        'type' => 'select',
        'label' => __('Page Sidebar Layout','vw-parallax'),
        'description' => __('Here you can change the sidebar layout for pages. ','vw-parallax'),
        'section' => 'vw_parallax_left_right',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','vw-parallax'),
            'Right Sidebar' => __('Right Sidebar','vw-parallax'),
            'One Column' => __('One Column','vw-parallax')
        ),
	) );

	//Woocommerce Shop Page Sidebar
	$wp_customize->add_setting( 'vw_parallax_woocommerce_shop_page_sidebar',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_parallax_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Parallax_Toggle_Switch_Custom_Control( $wp_customize, 'vw_parallax_woocommerce_shop_page_sidebar',array(
		'label' => esc_html__( 'Shop Page Sidebar','vw-parallax' ),
		'section' => 'vw_parallax_left_right'
    )));

    //Woocommerce Single Product page Sidebar
	$wp_customize->add_setting( 'vw_parallax_woocommerce_single_product_page_sidebar',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_parallax_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Parallax_Toggle_Switch_Custom_Control( $wp_customize, 'vw_parallax_woocommerce_single_product_page_sidebar',array(
		'label' => esc_html__( 'Single Product Sidebar','vw-parallax' ),
		'section' => 'vw_parallax_left_right'
    )));

	//Pre-Loader
	$wp_customize->add_setting( 'vw_parallax_loader_enable',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_parallax_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Parallax_Toggle_Switch_Custom_Control( $wp_customize, 'vw_parallax_loader_enable',array(
        'label' => esc_html__( 'Pre-Loader','vw-parallax' ),
        'section' => 'vw_parallax_left_right'
    )));

	$wp_customize->add_setting('vw_parallax_loader_icon',array(
        'default' => __('Two Way','vw-parallax'),
        'sanitize_callback' => 'vw_parallax_sanitize_choices'
	));
	$wp_customize->add_control('vw_parallax_loader_icon',array(
        'type' => 'select',
        'label' => __('Pre-Loader Type','vw-parallax'),
        'section' => 'vw_parallax_left_right',
        'choices' => array(
            'Two Way' => __('Two Way','vw-parallax'),
            'Dots' => __('Dots','vw-parallax'),
            'Rotate' => __('Rotate','vw-parallax')
        ),
	) );

	//Topbar
	$wp_customize->add_section( 'vw_parallax_topbar', array(
    	'title'      => __( 'Topbar Settings', 'vw-parallax' ),
		'priority'   => 30,
		'panel' => 'vw_parallax_panel_id'
	) );

	$wp_customize->add_setting( 'vw_parallax_topbar_hide_show',
       array(
          'default' => 1,
          'transport' => 'refresh',
          'sanitize_callback' => 'vw_parallax_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Parallax_Toggle_Switch_Custom_Control( $wp_customize, 'vw_parallax_topbar_hide_show',
       array(
          'label' => esc_html__( 'Show / Hide Topbar','vw-parallax' ),
          'section' => 'vw_parallax_topbar'
    )));

    //Sticky Header
	$wp_customize->add_setting( 'vw_parallax_sticky_header',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_parallax_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Parallax_Toggle_Switch_Custom_Control( $wp_customize, 'vw_parallax_sticky_header',array(
        'label' => esc_html__( 'Sticky Header','vw-parallax' ),
        'section' => 'vw_parallax_topbar'
    )));

	$wp_customize->add_setting( 'vw_parallax_search_hide_show',
       array(
          'default' => 1,
          'transport' => 'refresh',
          'sanitize_callback' => 'vw_parallax_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Parallax_Toggle_Switch_Custom_Control( $wp_customize, 'vw_parallax_search_hide_show',
       array(
          'label' => esc_html__( 'Show / Hide Search','vw-parallax' ),
          'section' => 'vw_parallax_topbar'
    )));

	$wp_customize->add_setting('vw_parallax_phone',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_parallax_phone',array(
		'label'	=> __('Add Phone no.','vw-parallax'),
		'input_attrs' => array(
            'placeholder' => __( '+00 123 456 7890', 'vw-parallax' ),
        ),
		'section'=> 'vw_parallax_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_parallax_email_address',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_parallax_email_address',array(
		'label'	=> __('Add Email Address','vw-parallax'),
		'input_attrs' => array(
            'placeholder' => __( 'support@example.com', 'vw-parallax' ),
        ),
		'section'=> 'vw_parallax_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_parallax_timming',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_parallax_timming',array(
		'label'	=> __('Add Timming','vw-parallax'),
		'input_attrs' => array(
            'placeholder' => __( 'Mon to Fri 8:00AM - 2:00PM', 'vw-parallax' ),
        ),
		'section'=> 'vw_parallax_topbar',
		'type'=> 'text'
	));	
    
	//Slider
	$wp_customize->add_section( 'vw_parallax_slidersettings' , array(
    	'title'      => __( 'Slider Section', 'vw-parallax' ),
		'priority'   => null,
		'panel' => 'vw_parallax_panel_id'
	) );

	$wp_customize->add_setting( 'vw_parallax_slider_hide_show',
       array(
          'default' => 1,
          'transport' => 'refresh',
          'sanitize_callback' => 'vw_parallax_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Parallax_Toggle_Switch_Custom_Control( $wp_customize, 'vw_parallax_slider_hide_show',
       array(
          'label' => esc_html__( 'Show / Hide Slider','vw-parallax' ),
          'section' => 'vw_parallax_slidersettings'
    )));

	for ( $count = 1; $count <= 4; $count++ ) {

		$wp_customize->add_setting( 'vw_parallax_slider_page' . $count, array(
			'default'           => '',
			'sanitize_callback' => 'vw_parallax_sanitize_dropdown_pages'
		) );
		$wp_customize->add_control( 'vw_parallax_slider_page' . $count, array(
			'label'    => __( 'Select Slide Image Page', 'vw-parallax' ),
			'description' => __('Slider image size (1500 x 590)','vw-parallax'),
			'section'  => 'vw_parallax_slidersettings',
			'type'     => 'dropdown-pages'
		) );
	}

	//content layout
	$wp_customize->add_setting('vw_parallax_slider_content_option',array(
        'default' => __('Center','vw-parallax'),
        'sanitize_callback' => 'vw_parallax_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Parallax_Image_Radio_Control($wp_customize, 'vw_parallax_slider_content_option', array(
        'type' => 'select',
        'label' => __('Slider Content Layouts','vw-parallax'),
        'section' => 'vw_parallax_slidersettings',
        'choices' => array(
            'Left' => get_template_directory_uri().'/assets/images/slider-content1.png',
            'Center' => get_template_directory_uri().'/assets/images/slider-content2.png',
            'Right' => get_template_directory_uri().'/assets/images/slider-content3.png',
    ))));

    //Slider excerpt
	$wp_customize->add_setting( 'vw_parallax_slider_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'absint',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'vw_parallax_slider_excerpt_number', array(
		'label'       => esc_html__( 'Slider Excerpt length','vw-parallax' ),
		'section'     => 'vw_parallax_slidersettings',
		'type'        => 'range',
		'settings'    => 'vw_parallax_slider_excerpt_number',
		'input_attrs' => array(
			'step'             => 2,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	//Opacity
	$wp_customize->add_setting('vw_parallax_slider_opacity_color',array(
      'default'              => 0.5,
      'sanitize_callback' => 'vw_parallax_sanitize_choices'
	));

	$wp_customize->add_control( 'vw_parallax_slider_opacity_color', array(
	'label'       => esc_html__( 'Slider Image Opacity','vw-parallax' ),
	'section'     => 'vw_parallax_slidersettings',
	'type'        => 'select',
	'settings'    => 'vw_parallax_slider_opacity_color',
	'choices' => array(
      '0' =>  esc_attr('0','vw-parallax'),
      '0.1' =>  esc_attr('0.1','vw-parallax'),
      '0.2' =>  esc_attr('0.2','vw-parallax'),
      '0.3' =>  esc_attr('0.3','vw-parallax'),
      '0.4' =>  esc_attr('0.4','vw-parallax'),
      '0.5' =>  esc_attr('0.5','vw-parallax'),
      '0.6' =>  esc_attr('0.6','vw-parallax'),
      '0.7' =>  esc_attr('0.7','vw-parallax'),
      '0.8' =>  esc_attr('0.8','vw-parallax'),
      '0.9' =>  esc_attr('0.9','vw-parallax')
	),
	));

	//Services
	$wp_customize->add_section( 'vw_parallax_service_section' , array(
    	'title'      => __( 'Services Section', 'vw-parallax' ),
		'priority'   => null,
		'panel' => 'vw_parallax_panel_id'
	) );

	$categories = get_categories();
	$cat_post = array();
	$cat_post[]= 'select';
	$i = 0;	
	foreach($categories as $category){
		if($i==0){
			$default = $category->slug;
			$i++;
		}
		$cat_post[$category->slug] = $category->name;
	}

	$wp_customize->add_setting('vw_parallax_services',array(
		'default'	=> 'select',
		'sanitize_callback' => 'vw_parallax_sanitize_choices',
	));
	$wp_customize->add_control('vw_parallax_services',array(
		'type'    => 'select',
		'choices' => $cat_post,
		'label' => __('Select Category to display services','vw-parallax'),
		'description' => __('Image Size (50 x 45)','vw-parallax'),
		'section' => 'vw_parallax_service_section',
	));

	//Services excerpt
	$wp_customize->add_setting( 'vw_parallax_services_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'absint',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'vw_parallax_services_excerpt_number', array(
		'label'       => esc_html__( 'Services Excerpt length','vw-parallax' ),
		'section'     => 'vw_parallax_service_section',
		'type'        => 'range',
		'settings'    => 'vw_parallax_services_excerpt_number',
		'input_attrs' => array(
			'step'             => 2,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	//About Section
	$wp_customize->add_section( 'vw_parallax_about_section' , array(
    	'title'      => __( 'About us Section', 'vw-parallax' ),
		'priority'   => null,
		'panel' => 'vw_parallax_panel_id'
	) );

	$wp_customize->add_setting('vw_parallax_section_main_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_parallax_section_main_title',array(
		'label'	=> __('Section Title','vw-parallax'),
		'input_attrs' => array(
            'placeholder' => __( 'ABOUT US', 'vw-parallax' ),
        ),
		'section'=> 'vw_parallax_about_section',
		'setting'=> 'vw_parallax_section_main_title',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'vw_parallax_about_page', array(
		'default'           => '',
		'sanitize_callback' => 'vw_parallax_sanitize_dropdown_pages'
	) );
	$wp_customize->add_control( 'vw_parallax_about_page', array(
		'label'    => __( 'About Page', 'vw-parallax' ),
		'section'  => 'vw_parallax_about_section',
		'type'     => 'dropdown-pages'
	) );

	//About excerpt
	$wp_customize->add_setting( 'vw_parallax_about_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'absint',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'vw_parallax_about_excerpt_number', array(
		'label'       => esc_html__( 'About Excerpt length','vw-parallax' ),
		'section'     => 'vw_parallax_about_section',
		'type'        => 'range',
		'settings'    => 'vw_parallax_about_excerpt_number',
		'input_attrs' => array(
			'step'             => 2,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	//Blog Post
	$wp_customize->add_section('vw_parallax_blog_post',array(
		'title'	=> __('Blog Post Settings','vw-parallax'),
		'panel' => 'vw_parallax_panel_id',
	));	

	$wp_customize->add_setting( 'vw_parallax_toggle_postdate',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_parallax_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Parallax_Toggle_Switch_Custom_Control( $wp_customize, 'vw_parallax_toggle_postdate',array(
        'label' => esc_html__( 'Post Date','vw-parallax' ),
        'section' => 'vw_parallax_blog_post'
    )));

    $wp_customize->add_setting( 'vw_parallax_toggle_author',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_parallax_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Parallax_Toggle_Switch_Custom_Control( $wp_customize, 'vw_parallax_toggle_author',array(
		'label' => esc_html__( 'Author','vw-parallax' ),
		'section' => 'vw_parallax_blog_post'
    )));

    $wp_customize->add_setting( 'vw_parallax_toggle_comments',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_parallax_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Parallax_Toggle_Switch_Custom_Control( $wp_customize, 'vw_parallax_toggle_comments',array(
		'label' => esc_html__( 'Comments','vw-parallax' ),
		'section' => 'vw_parallax_blog_post'
    )));

    $wp_customize->add_setting( 'vw_parallax_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'absint',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'vw_parallax_excerpt_number', array(
		'label'       => esc_html__( 'Excerpt length','vw-parallax' ),
		'section'     => 'vw_parallax_blog_post',
		'type'        => 'range',
		'settings'    => 'vw_parallax_excerpt_number',
		'input_attrs' => array(
			'step'             => 2,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	//Blog layout
    $wp_customize->add_setting('vw_parallax_blog_layout_option',array(
        'default' => __('Default','vw-parallax'),
        'sanitize_callback' => 'vw_parallax_sanitize_choices'
    ));
    $wp_customize->add_control(new VW_Parallax_Image_Radio_Control($wp_customize, 'vw_parallax_blog_layout_option', array(
        'type' => 'select',
        'label' => __('Blog Layouts','vw-parallax'),
        'section' => 'vw_parallax_blog_post',
        'choices' => array(
            'Default' => get_template_directory_uri().'/assets/images/blog-layout1.png',
            'Center' => get_template_directory_uri().'/assets/images/blog-layout2.png',
            'Left' => get_template_directory_uri().'/assets/images/blog-layout3.png',
    ))));

    //404 Page Setting
	$wp_customize->add_section('vw_parallax_404_page',array(
		'title'	=> __('404 Page Settings','vw-parallax'),
		'panel' => 'vw_parallax_panel_id',
	));	

	$wp_customize->add_setting('vw_parallax_404_page_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('vw_parallax_404_page_title',array(
		'label'	=> __('Add Title','vw-parallax'),
		'input_attrs' => array(
            'placeholder' => __( '404 Not Found', 'vw-parallax' ),
        ),
		'section'=> 'vw_parallax_404_page',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_parallax_404_page_content',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('vw_parallax_404_page_content',array(
		'label'	=> __('Add Text','vw-parallax'),
		'input_attrs' => array(
            'placeholder' => __( 'Looks like you have taken a wrong turn, Dont worry, it happens to the best of us.', 'vw-parallax' ),
        ),
		'section'=> 'vw_parallax_404_page',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_parallax_404_page_button_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_parallax_404_page_button_text',array(
		'label'	=> __('Add Button Text','vw-parallax'),
		'input_attrs' => array(
            'placeholder' => __( 'Return to the home page', 'vw-parallax' ),
        ),
		'section'=> 'vw_parallax_404_page',
		'type'=> 'text'
	));

	//Responsive Media Settings
	$wp_customize->add_section('vw_parallax_responsive_media',array(
		'title'	=> __('Responsive Media','vw-parallax'),
		'panel' => 'vw_parallax_panel_id',
	));

	$wp_customize->add_setting( 'vw_parallax_resp_topbar_hide_show',array(
          'default' => 1,
          'transport' => 'refresh',
          'sanitize_callback' => 'vw_parallax_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Parallax_Toggle_Switch_Custom_Control( $wp_customize, 'vw_parallax_resp_topbar_hide_show',array(
          'label' => esc_html__( 'Show / Hide Topbar','vw-parallax' ),
          'section' => 'vw_parallax_responsive_media'
    )));

    $wp_customize->add_setting( 'vw_parallax_stickyheader_hide_show',array(
          'default' => 1,
          'transport' => 'refresh',
          'sanitize_callback' => 'vw_parallax_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Parallax_Toggle_Switch_Custom_Control( $wp_customize, 'vw_parallax_stickyheader_hide_show',array(
          'label' => esc_html__( 'Sticky Header','vw-parallax' ),
          'section' => 'vw_parallax_responsive_media'
    )));

    $wp_customize->add_setting( 'vw_parallax_resp_slider_hide_show',array(
          'default' => 1,
          'transport' => 'refresh',
          'sanitize_callback' => 'vw_parallax_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Parallax_Toggle_Switch_Custom_Control( $wp_customize, 'vw_parallax_resp_slider_hide_show',array(
          'label' => esc_html__( 'Show / Hide Slider','vw-parallax' ),
          'section' => 'vw_parallax_responsive_media'
    )));

	$wp_customize->add_setting( 'vw_parallax_metabox_hide_show',array(
          'default' => 1,
          'transport' => 'refresh',
          'sanitize_callback' => 'vw_parallax_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Parallax_Toggle_Switch_Custom_Control( $wp_customize, 'vw_parallax_metabox_hide_show',array(
          'label' => esc_html__( 'Show / Hide Metabox','vw-parallax' ),
          'section' => 'vw_parallax_responsive_media'
    )));

    $wp_customize->add_setting( 'vw_parallax_sidebar_hide_show',array(
          'default' => 1,
          'transport' => 'refresh',
          'sanitize_callback' => 'vw_parallax_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Parallax_Toggle_Switch_Custom_Control( $wp_customize, 'vw_parallax_sidebar_hide_show',array(
          'label' => esc_html__( 'Show / Hide Sidebar','vw-parallax' ),
          'section' => 'vw_parallax_responsive_media'
    )));

	//Content Creation
	$wp_customize->add_section( 'vw_parallax_content_section' , array(
    	'title' => __( 'Customize Home Page', 'vw-parallax' ),
		'priority' => null,
		'panel' => 'vw_parallax_panel_id'
	) );

	$wp_customize->add_setting('vw_parallax_content_creation_main_control', array(
		'sanitize_callback' => 'esc_html',
	) );

	$homepage= get_option( 'page_on_front' );

	$wp_customize->add_control(	new VW_Parallax_Content_Creation( $wp_customize, 'vw_parallax_content_creation_main_control', array(
		'options' => array(
			esc_html__( 'First select static page in homepage setting for front page.Below given edit button is to customize Home Page. Just click on the edit option, add whatever elements you want to include in the homepage, save the changes and you are good to go.','vw-parallax' ),
		),
		'section' => 'vw_parallax_content_section',
		'button_url'  => admin_url( 'post.php?post='.$homepage.'&action=edit'),
		'button_text' => esc_html__( 'Edit', 'vw-parallax' ),
	) ) );

	//Footer Text
	$wp_customize->add_section('vw_parallax_footer',array(
		'title'	=> __('Footer','vw-parallax'),
		'description'=> __('This section will appear in the footer','vw-parallax'),
		'panel' => 'vw_parallax_panel_id',
	));	
	
	$wp_customize->add_setting('vw_parallax_footer_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_parallax_footer_text',array(
		'label'	=> __('Copyright Text','vw-parallax'),
		'input_attrs' => array(
            'placeholder' => __( 'Copyright 2018, .....', 'vw-parallax' ),
        ),
		'section'=> 'vw_parallax_footer',
		'setting'=> 'vw_parallax_footer_text',
		'type'=> 'text'
	));	

	$wp_customize->add_setting( 'vw_parallax_hide_show_scroll',array(
    	'default' => 1,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'vw_parallax_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Parallax_Toggle_Switch_Custom_Control( $wp_customize, 'vw_parallax_hide_show_scroll',array(
      	'label' => esc_html__( 'Show / Hide Scroll To Top','vw-parallax' ),
      	'section' => 'vw_parallax_footer'
    )));

	$wp_customize->add_setting('vw_parallax_scroll_top_alignment',array(
        'default' => __('Right','vw-parallax'),
        'sanitize_callback' => 'vw_parallax_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Parallax_Image_Radio_Control($wp_customize, 'vw_parallax_scroll_top_alignment', array(
        'type' => 'select',
        'label' => __('Scroll To Top','vw-parallax'),
        'section' => 'vw_parallax_footer',
        'settings' => 'vw_parallax_scroll_top_alignment',
        'choices' => array(
            'Left' => get_template_directory_uri().'/assets/images/layout1.png',
            'Center' => get_template_directory_uri().'/assets/images/layout2.png',
            'Right' => get_template_directory_uri().'/assets/images/layout3.png'
    ))));
}

add_action( 'customize_register', 'vw_parallax_customize_register' );

load_template( trailingslashit( get_template_directory() ) . '/inc/logo/logo-resizer.php' );

/**
 * Singleton class for handling the theme's customizer integration.
 *
 * @since  1.0.0
 * @access public
 */
final class VW_Parallax_Customize {

	/**
	 * Returns the instance.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return object
	 */
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	/**
	 * Constructor method.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function __construct() {}

	/**
	 * Sets up initial actions.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}

	/**
	 * Sets up the customizer sections.
	 *
	 * @since  1.0.0
	 * @access public
	 * @param  object  $manager
	 * @return void
	 */
	public function sections( $manager ) {

		// Load custom sections.
		load_template( trailingslashit( get_template_directory() ) . '/inc/section-pro.php' );

		// Register custom section types.
		$manager->register_section_type( 'VW_Parallax_Customize_Section_Pro' );

		// Register sections.
		$manager->add_section(new VW_Parallax_Customize_Section_Pro($manager,'example_1',array(
			'priority'   => 1,
			'title'    => esc_html__( 'PARALLAX PRO', 'vw-parallax' ),
			'pro_text' => esc_html__( 'UPGRADE PRO', 'vw-parallax' ),
			'pro_url'  => esc_url('https://www.vwthemes.com/themes/parallax-wordpress-theme/'),
		)));

		$manager->add_section(new VW_Parallax_Customize_Section_Pro($manager,'example_2',array(
			'priority'   => 1,
			'title'    => esc_html__( 'DOCUMENTATION', 'vw-parallax' ),
			'pro_text' => esc_html__( 'DOCS', 'vw-parallax' ),
			'pro_url'  => admin_url('themes.php?page=vw_parallax_guide'),
		)));
	}

	/**
	 * Loads theme customizer CSS.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function enqueue_control_scripts() {

		wp_enqueue_script( 'vw-parallax-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/js/customize-controls.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'vw-parallax-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/css/customize-controls.css' );
	}
}

// Doing this customizer thang!
VW_Parallax_Customize::get_instance();